import React from "react";

export function useDebounce<T>(value: T, delay?: number): T {
  const [debouncedValue, setDebouncedValue] =
    React.useState<T>(value);

  React.useEffect(() => {
    const timer = setTimeout(
      () => setDebouncedValue(value),
      delay || 500
    );

    return () => {
      clearTimeout(timer);
    };
  }, [value, delay]);

  return debouncedValue;
}

export default useDebounce;
